@@ -1,20 +1,28 @@
 <?php
 
 // Sort types
-/** @const NAG_SORT_NAME Sort by task name.           */ define('NAG_SORT_NAME', 'name');
-/** @const NAG_SORT_PRIORITY Sort by priority.        */ define('NAG_SORT_PRIORITY', 'priority');
-/** @const NAG_SORT_DUE Sort by due date.             */ define('NAG_SORT_DUE', 'due');
-/** @const NAG_SORT_COMPLETION Sort by completion.    */ define('NAG_SORT_COMPLETION', 'completed');
-/** @const NAG_SORT_CATEGORY Sort by category.        */ define('NAG_SORT_CATEGORY', 'category');
-/** @const NAG_SORT_OWNER Sort by owner.              */ define('NAG_SORT_OWNER', 'tasklist_id');
+/** Sort by task name. */
+define('NAG_SORT_NAME', 'name');
+/** Sort by priority. */
+define('NAG_SORT_PRIORITY', 'priority');
+/** Sort by due date. */
+define('NAG_SORT_DUE', 'due');
+/** Sort by completion. */
+define('NAG_SORT_COMPLETION', 'completed');
+/** Sort by category. */
+define('NAG_SORT_CATEGORY', 'category');
+/** Sort by owner. */
+define('NAG_SORT_OWNER', 'tasklist_id');
 
-/** @const NAG_SORT_ASCEND Sort in ascending order.   */ define('NAG_SORT_ASCEND', 0);
-/** @const NAG_SORT_DESCEND Sort in descending order. */ define('NAG_SORT_DESCEND', 1);
+/** Sort in ascending order. */
+define('NAG_SORT_ASCEND', 0);
+/** Sort in descending order. */
+define('NAG_SORT_DESCEND', 1);
 
 /**
  * Nag Base Class.
  *
- * $Horde: nag/lib/Nag.php,v 1.124.2.3 2005/01/21 20:09:52 chuck Exp $
+ * $Horde: nag/lib/Nag.php,v 1.124.2.8 2005/10/10 01:41:20 selsky Exp $
  *
  * @author  Jon Parise <jon@horde.org>
  * @package Nag
@@ -29,15 +37,15 @@ class Nag {
         if ($hours > 1) {
             if ($minutes == 0) {
                 return sprintf(_("%d hours"), $hours);
-            } else if ($minutes == 1) {
+            } elseif ($minutes == 1) {
                 return sprintf(_("%d hours, %d minute"), $hours, $minutes);
             } else {
                 return sprintf(_("%d hours, %d minutes"), $hours, $minutes);
             }
-        } else if ($hours == 1) {
+        } elseif ($hours == 1) {
             if ($minutes == 0) {
                 return sprintf(_("%d hour"), $hours);
-            } else if ($minutes == 1) {
+            } elseif ($minutes == 1) {
                 return sprintf(_("%d hour, %d minute"), $hours, $minutes);
             } else {
                 return sprintf(_("%d hour, %d minutes"), $hours, $minutes);
@@ -45,7 +53,7 @@ class Nag {
         } else {
             if ($minutes == 0) {
                 return _("no time");
-            } else if ($minutes == 1) {
+            } elseif ($minutes == 1) {
                 return sprintf(_("%d minute"), $minutes);
             } else {
                 return sprintf(_("%d minutes"), $minutes);
@@ -57,13 +65,13 @@ class Nag {
      * Retrieves the current user's task list from storage.
      * This function will also sort the resulting list, if requested.
      *
-     * @param object Nag_Driver $storage   The current storage object.
-     * @param constant $sortby     (optional) The field by which to sort.
+     * @param Nag_Driver $storage  The current storage object.
+     * @param constant $sortby     The field by which to sort
      *                             (NAG_SORT_PRIORITY, NAG_SORT_NAME
-     *                              NAG_SORT_DUE, NAG_SORT_COMPLETION)
-     * @param constant $sortdir    (optional) The direction by which to sort.
-     *                             (NAG_SORT_ASC, NAG_SORT_DESC)
-     * @param constant $altsortby  (optional) The secondary sort field.
+     *                             NAG_SORT_DUE, NAG_SORT_COMPLETION).
+     * @param constant $sortdir    The direction by which to sort
+     *                             (NAG_SORT_ASC, NAG_SORT_DESC).
+     * @param constant $altsortby  The secondary sort field.
      *
      * @return array  A list of the requested tasks.
      *
@@ -108,26 +116,29 @@ class Nag {
             }
 
             foreach ($newtasks as $taskID => $task) {
-                $url = Util::addParameter('view.php', 'task', $task['task_id']);
-                $url = Util::addParameter($url, 'tasklist', $task['tasklist_id']);
+                $url = Util::addParameter('view.php',
+                                          array('task' => $task['task_id'],
+                                                'tasklist' => $task['tasklist_id']));
                 $newtasks[$taskID]['view_link'] = Horde::applicationUrl($url);
 
-                $url = Util::addParameter('task.php', 'task', $task['task_id']);
-                $url = Util::addParameter($url, 'tasklist', $task['tasklist_id']);
-                $newtasks[$taskID]['complete_link'] = Horde::applicationUrl(Util::addParameter($url, 'actionID', 'complete_task'));
-                $newtasks[$taskID]['edit_link'] = Horde::applicationUrl(Util::addParameter($url, 'actionID', 'modify_task'));
-                $newtasks[$taskID]['delete_link'] = Horde::applicationUrl(Util::addParameter($url, 'actionID', 'delete_tasks'));
+                $url = Util::addParameter('task.php',
+                                          array('task' => $task['task_id'],
+                                                'tasklist' => $task['tasklist_id']));
+                $url = Horde::applicationUrl($url);
+                $newtasks[$taskID]['complete_link'] = Util::addParameter($url, 'actionID', 'complete_task');
+                $newtasks[$taskID]['edit_link'] = Util::addParameter($url, 'actionID', 'modify_task');
+                $newtasks[$taskID]['delete_link'] = Util::addParameter($url, 'actionID', 'delete_tasks');
             }
 
             $tasks = array_merge($tasks, $newtasks);
         }
 
-        /* We look for registered apis that support
-         * listAs(taskHash). */
+        /* We look for registered apis that support listAs(taskHash). */
         $apps = @unserialize($prefs->getValue('show_external'));
         if (is_array($apps)) {
             foreach ($apps as $app) {
-                if ($app != 'nag' && $registry->hasMethod('getListTypes', $app)) {
+                if ($app != 'nag' &&
+                    $registry->hasMethod('getListTypes', $app)) {
                     $types = $registry->callByPackage($app, 'getListTypes');
                     if (!empty($types['taskHash'])) {
                         $newtasks = $registry->callByPackage($app, 'listAs', array('taskHash'));
@@ -141,8 +152,8 @@ class Nag {
             }
         }
 
-        /* Filter complete/incomplete tasks if the user doesn't want
-         * them shown. */
+        /* Filter complete/incomplete tasks if the user doesn't want them
+         * shown. */
         switch ($prefs->getValue('show_completed')) {
         case 0:
             foreach ($tasks as $taskID => $task) {
@@ -194,7 +205,7 @@ class Nag {
     /**
      * Returns all the alarms active right on $date.
      *
-     * @param object $date         The start of the time range.
+     * @param object $date  The start of the time range.
      *
      * @return array  The alarms (alarmId) active on $date.
      */
@@ -226,11 +237,11 @@ class Nag {
     }
 
     /**
-     * List all task lists a user has access to.
+     * Lists all task lists a user has access to.
      *
-     * @param optional boolean $owneronly  Only return tasklists that this
-     *                                     user owns? Defaults to false.
-     * @param optional integer $permission The permission to filter tasklists by.
+     * @param boolean $owneronly  Only return tasklists that this user owns?
+     *                            Defaults to false.
+     * @param integer $permission The permission to filter tasklists by.
      *
      * @return array  The task lists.
      */
@@ -246,7 +257,7 @@ class Nag {
     }
 
     /**
-     * Get the default tasklist for the current user at the specified
+     * Returns the default tasklist for the current user at the specified
      * permissions level.
      */
     function getDefaultTasklist($permission = PERMS_SHOW)
@@ -270,10 +281,10 @@ class Nag {
     /**
      * Builds the HTML for a priority selection widget.
      *
-     * @param string  $name         The name of the widget.
-     * @param integer $selected     (optional) The default selected priority.
+     * @param string $name       The name of the widget.
+     * @param integer $selected  The default selected priority.
      *
-     * @return string       The HTML <select> widget.
+     * @return string  The HTML <select> widget.
      */
     function buildPriorityWidget($name, $selected = -1)
     {
@@ -293,23 +304,24 @@ class Nag {
     /**
      * Builds the HTML for a task completion state widget.
      *
-     * @param string  $name     The name of the widget.
-     * @param integer $checked  (optional) The default completion state.
+     * @param string $name      The name of the widget.
+     * @param integer $checked  The default completion state.
      *
      * @return string  HTML for a checkbox representing the completion state.
      */
     function buildCompletionWidget($name, $checked = 0)
     {
         $name = htmlspecialchars($name);
-        return "<input type=\"checkbox\" id=\"$name\" name=\"$name\"" . ($checked ? ' checked="checked"' : '') . ' />';
+        return "<input type=\"checkbox\" id=\"$name\" name=\"$name\"" .
+            ($checked ? ' checked="checked"' : '') . ' />';
     }
 
     /**
      * Formats the given Unix-style date string.
      *
-     * @param string $unixdate     The Unix-style date value to format.
+     * @param string $unixdate  The Unix-style date value to format.
      *
-     * @return string       The formatted due date string.
+     * @return string  The formatted due date string.
      */
     function formatDate($unixdate = '')
     {
@@ -321,15 +333,15 @@ class Nag {
 
         return sprintf(_("%s at %s"),
                        strftime($prefs->getValue('date_format'), $unixdate),
-                       strftime($prefs->getValue('twentyFour') ? '%H:%M' : '%I:%M %P', $unixdate));
+                       strftime($prefs->getValue('twentyFour') ? '%H:%M' : '%I:%M %p', $unixdate));
     }
 
     /**
      * Returns the string representation of the given completion status.
      *
-     * @param int $completed    The completion value.
+     * @param int $completed  The completion value.
      *
-     * @return string       The HTML representation of $completed.
+     * @return string  The HTML representation of $completed.
      */
     function formatCompletion($completed)
     {
@@ -341,21 +353,22 @@ class Nag {
     /**
      * Returns a colored representation of a priority.
      *
-     * @param int $priority    The priority level.
+     * @param int $priority  The priority level.
      *
-     * @return string       The HTML representation of $priority.
+     * @return string  The HTML representation of $priority.
      */
     function formatPriority($priority)
     {
-        return '<span class="pri-' . (int)$priority . '">' . (int)$priority . '</span>';
+        return '<span class="pri-' . (int)$priority . '">' . (int)$priority .
+            '</span>';
     }
 
     /**
      * Returns the string matching the given alarm value.
      *
-     * @param int  $value       The alarm value in minutes.
+     * @param int $value  The alarm value in minutes.
      *
-     * @return string       The formatted alarm string.
+     * @return string  The formatted alarm string.
      */
     function formatAlarm($value)
     {
@@ -382,8 +395,6 @@ class Nag {
 
     /**
      * Build Nag's list of menu items.
-     *
-     * @access public
      */
     function getMenu($returnType = 'object')
     {
@@ -451,8 +462,8 @@ class Nag {
             }
         }
 
-        // Check here for guest task lists so that we don't get
-        // multiple messages after redirects, etc.
+        // Check here for guest task lists so that we don't get multiple
+        // messages after redirects, etc.
         if (!Auth::getAuth() && !count(Nag::listTasklists())) {
             $notification->push(_("No task lists are available to guests."));
         }
@@ -467,7 +478,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByPriority($a, $b)
     {
@@ -481,7 +493,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater, 1 if task two is greater; 0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _rsortByPriority($a, $b)
     {
@@ -495,7 +508,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByName($a, $b)
     {
@@ -508,7 +522,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater, 1 if task two is greater; 0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _rsortByName($a, $b)
     {
@@ -521,11 +536,12 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByCategory($a, $b)
     {
-        return strcasecmp($b['category'], $a['category']);
+        return strcasecmp($a['category'], $b['category']);
     }
 
     /**
@@ -534,7 +550,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater, 1 if task two is greater; 0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _rsortByCategory($a, $b)
     {
@@ -547,7 +564,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByDue($a, $b)
     {
@@ -572,9 +590,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater,
-     *                   1 if task two is greater,
-     *                   0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater,
+     *                  0 if they are equal.
      */
     function _rsortByDue($a, $b)
     {
@@ -599,7 +616,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByCompletion($a, $b)
     {
@@ -613,7 +631,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater, 1 if task two is greater; 0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _rsortByCompletion($a, $b)
     {
@@ -627,7 +646,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  1 if task one is greater, -1 if task two is greater; 0 if they are equal.
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _sortByOwner($a, $b)
     {
@@ -653,7 +673,8 @@ class Nag {
      * @param array $a  Task one.
      * @param array $b  Task two.
      *
-     * @return integer  -1 if task one is greater, 1 if task two is greater; 0 if they are equal.
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
      */
     function _rsortByOwner($a, $b)
     {
